PCB Environment: Data Structures

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures
Here are the data structures with brief descriptions:
[detail level 12]

Ndsn |
C BBox |
C PCB |
C Layer |
C Segment |
C Via |
C Track |
C Connection |
C Net |
C Path |
C Shape |
C Padstack |
C Pin |
C Image |
C Structure |
C Placement |
C Data |
Nmath |
C Mat4 |
C Moments |
Npy |
C GIL_guard | The GIL
C NPArray |
C Object | NOTE: This does not do any automatic reference counting
C BorrowedRef |
C ObjectRef |
C DictIterator |
Nrewards |
C RouteLength |
Nui |
C NavGrid |
C Action | NOTE: Actions always set the Agent's least recently used connction (getConnectionLRU()) which is somewhat ugly for actions affecting multiple connections - we should probably return a set of affected connections if we ever have actions that change more than one (other than clustering which doesn't really change anything)
C Result |
C ActionCache |
C ActionSet |
C ActionSpace |
C ActionTab |
C Agent |
C AlignedTHPAllocator |
C AShape |
C AStar |
C AStarCosts |
C AStarVisitStatus |
C BaseROP |
C BrowserTab |
C Camera |
C CircleEx |
C CloneEnv |
C Color |
C Component |
C Connection |
C DRCViolation |
C DSNParserBase |
C Env |
C EnvPCB |
C fancy_lock_guard |
C GLWidget |
C GridDirection |
C IBox_3 |
C IndexRange |
C IPoint_2 |
C IPoint_3 |
C IsoRectEx |
C IUIApplication |
C IVector_2 |
C IVector_3 |
C Layer |
C LayerAlphaSlider |
C LayoutArea |
C Length |
C LogFile |
C Logger |
C LubySequence |
C NavGrid | The grid-representation of the board
C NavImage |
C NavKeepoutCounts |
C NavMesh |
C NavPixel |
C NavPoint |
C NavPointRef |
C NavRasterizeParams |
C NavSpacings | This struct stores the spacing requirements the NavGrid is/should be prepared for
C NavTri | Data associated with a triangle in the Delaunay triangulation of the board
C NavTriangulation | Interface to the Delaunay triangulation
C Net |
C NetOverrides |
C NetTopology |
C Object |
C ObjectPtrNameLessThan |
C ObjectsBVH |
C Palette |
C Parameter |
C ParameterTab |
C Path |
C PCBFactory |
C PCBItemSets |
C PCBoard |
C PCBoardMesh |
C IndexRange |
C Pin |
C Point_25 |
C Policy |
C CommonParams |
C PolygonEx |
C Pusher |
C Rasterizer |
C RatsNest |
C RecordRangesROP |
C ResultCollection |
C ResultRecord |
C RewardFunction |
C RoutePainter |
C RoutePainterLines |
C RouterResult |
C RouteTracker |
C RRRAgent |
C Segment_25 |
C Shaders |
C SignalContext |
C StateRepresentation | The subclass create(PyObject *) functions check if the PyObject matches and return a new instace if it does, or 0 otherwise (or throw an exception if the name matches but the parameters don't)
C StepLock |
C Token |
C Track |
C TriangleEx |
C TriList |
C UIActions | WARNING: The non-async UIActions functions are expected to be non-concurrent
C UIApplication |
C UniformGrid25 |
C UserAgent |
C UserSettings |
C Via |
C ViaPainter |
C ViewTab |
C WideSegment_25 |
C Window |